# Camera


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **int** |  | [optional] [readonly] 
**deleted** | **datetime** |  | [optional] [readonly] 
**created_dt** | **datetime** |  | [optional] [readonly] 
**updated_dt** | **datetime** |  | [optional] [readonly] 
**user** | **int** |  | 
**device** | **int** |  | 
**name** | **str** |  | 
**camera_type** | [**CameraTypeEnum**](CameraTypeEnum.md) |  | [optional] 
**camera_source** | **str** |  | 
**url** | **str** |  | [optional] [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


